===========================
Iterative Ensemble Smoother
===========================

.. toctree::
   :hidden:
   :maxdepth: 1

   examples
   api
   glossary
   bibliography


A library for the iterative ensemble smoother algorithm.

The algorithm performs :term:`history matching` based on the method developed
in :cite:`evensen2018analysis`.



Quick Start Guide
=================

.. code-block:: console

    pip install iterative_ensemble_smoother



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
